@@ -46,6 +46,10 @@ class TestServiceModel(unittest.TestCase):
         service_model = ServiceModel(self.model, 'myservice')
         self.assertEqual(service_model.products, ['ALTUS'])
 
+    def test_endpoint_prefix(self):
+        service_model = ServiceModel(self.model, 'myservice')
+        self.assertEqual(service_model.endpoint_prefix, 'api')
+
     def test_operations(self):
         self.assertTrue(self.service_model.operation_model(
                 'createDirector') is not None)
